@@ -6,11 +6,17 @@ import click
 from ph_storage.model.hdfs_storage import PhHdfsStorage
 from ph_storage.model.local_storage import PhLocalStorage
 from ph_storage.model.s3_storage import PhS3Storage
-
+import json
 
 @click.command("hdfsbackup", short_help='HDFS数据备份到S3')
 @click.argument("paths")
 def main(paths):
+    if paths is None or paths == "{}":
+        paths = ["/logs/yarnLogs", "/logs/sparkLogs"]
+
+    if not isinstance(paths, list):
+        paths = paths.replace('[', '').replace(']', '').split(',')
+
     hdfs_ins = PhHdfsStorage(PhLocalStorage(), PhS3Storage())
     hdfs_ins.back_up(paths)
 
